PollRequestError

Enum PollRequestError 

#[non_exhaustive]
pub enum PollRequestError { WrongOwner, WrongKind, AlreadyCompleted, StaleGeneration, RecoveryFailed, }
Error returned when a request is polled through the wrong handle or after its terminal state.

Unlike RequestPoll::Ready, this is not a transfer terminal state for the request payload. Implementations must not report a terminal RequestPoll::Ready error until the controller is no longer accessing the transaction buffer.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WrongOwner



WrongKind



AlreadyCompleted



StaleGeneration



RecoveryFailed

Recovery could not be reported through the requested handle.

Safe host implementations must still quiesce the hardware before any request object that borrows caller memory can be dropped. This variant is diagnostic only; it must not mean DMA is still active.